@@ -5,11 +5,10 @@ import base64
 from Crypto.Cipher import AES
 
 from django.middleware.csrf import get_token
-from django.utils import six
-from django.utils.crypto import get_random_string
-from django.utils.encoding import smart_text
 from django.utils.functional import lazy
 
+from debreach.compat import get_random_string, smart_text, text_type
+
 
 def csrf(request):
     """
@@ -28,9 +27,9 @@ def csrf(request):
             aes = AES.new(key)
             padding = ''.join(' ' for x in range(16 - (len(token) % 16)))
             value = base64.encodestring(
-                aes.encrypt('{0}{1}'.format(token, padding)))
+                aes.encrypt('{0}{1}'.format(token, padding))).strip()
             token = '$'.join((key, value))
             return smart_text(token)
-    _get_val = lazy(_get_val, six.text_type)
+    _get_val = lazy(_get_val, text_type)
 
     return {'csrf_token': _get_val()}
