@@ -7,9 +7,9 @@ import random
 from Crypto.Cipher import AES
 
 from django.core.exceptions import SuspiciousOperation
-from django.utils import six
-from django.utils.crypto import get_random_string
-from django.utils.encoding import force_bytes
+
+from debreach.compat import force_bytes, get_random_string, string_types
+
 
 log = logging.getLogger(__name__)
 
@@ -23,9 +23,8 @@ class CSRFCryptMiddleware(object):
                 POST = request.POST.copy()
                 token = POST.get('csrfmiddlewaretoken')
                 key, value = token.split('$')
-                key = base64.decodestring(force_bytes(key)).strip()
                 value = base64.decodestring(force_bytes(value)).strip()
-                aes = AES.new(key)
+                aes = AES.new(key.strip())
                 POST['csrfmiddlewaretoken'] = aes.decrypt(value).strip()
                 POST._mutable = False
                 request.POST = POST
@@ -41,7 +40,7 @@ class RandomCommentMiddleware(object):
     def process_response(self, request, response):
         if not getattr(response, 'streaming', False) \
                 and response['Content-Type'] == 'text/html' \
-                and isinstance(response.content, six.string_types):
+                and isinstance(response.content, string_types):
             comment = '<!-- {0} -->'.format(
                 get_random_string(random.choice(range(12, 25))))
             response.content = '{0}{1}'.format(response.content, comment)
